@@ -34,17 +34,19 @@ const (
 	coreDNSRepoPath   = "eks/coredns"
 
 	// Largest eksbuild tag we will try looking for.
-	maxEKSBuild = 20
+	maxEKSBuild = 30
 )
 
 var (
 	// NOTE: Ensure that there is an entry for each supported version in the following tables.
-	supportedVersions = []string{"1.30", "1.29", "1.28", "1.27", "1.26", "1.25"}
+	supportedVersions = []string{"1.32", "1.31", "1.30", "1.29", "1.28", "1.27", "1.26", "1.25"}
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-coredns.html
 	coreDNSVersionLookupTable = map[string]string{
-		"1.30": "1.11.1-eksbuild",
-		"1.29": "1.11.1-eksbuild",
+		"1.32": "1.11.4-eksbuild",
+		"1.31": "1.11.3-eksbuild",
+		"1.30": "1.11.3-eksbuild",
+		"1.29": "1.11.3-eksbuild",
 		"1.28": "1.10.1-eksbuild",
 		"1.27": "1.10.1-eksbuild",
 		"1.26": "1.9.3-eksbuild",
@@ -53,6 +55,8 @@ var (
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-kube-proxy.html#updating-kube-proxy-add-on
 	kubeProxyVersionLookupTable = map[string]string{
+		"1.32": "1.32.0-minimal-eksbuild",
+		"1.31": "1.31.0-minimal-eksbuild",
 		"1.30": "1.30.3-minimal-eksbuild",
 		"1.29": "1.29.7-minimal-eksbuild",
 		"1.28": "1.28.12-minimal-eksbuild",
@@ -63,12 +67,14 @@ var (
 
 	// Reference: https://docs.aws.amazon.com/eks/latest/userguide/managing-vpc-cni.html
 	amazonVPCCNIVersionLookupTable = map[string]string{
-		"1.30": "1.18.3",
-		"1.29": "1.18.3",
-		"1.28": "1.18.3",
-		"1.27": "1.18.3",
-		"1.26": "1.18.3",
-		"1.25": "1.18.3",
+		"1.32": "1.19.2",
+		"1.31": "1.18.5",
+		"1.30": "1.18.5",
+		"1.29": "1.18.5",
+		"1.28": "1.18.5",
+		"1.27": "1.18.5",
+		"1.26": "1.18.5",
+		"1.25": "1.18.5",
 	}
 
 	defaultContainerImageAccount = "602401143452"
